@@ -40,6 +40,23 @@ class Connection:
         clone_args.update(kwargs)
         return self.__class__(**clone_args)
 
+    @property
+    def hostname(self):
+        return self._clone_data.get('mshost', None) or self._clone_data.get('ashost', '')
+
+    @property
+    def is_alive(self):
+        return self._connection.alive
+
+    def open(self):
+        self._connection.open()
+
+    def reopen(self):
+        self._connection.reopen()
+
+    def reset_server_context(self):
+        self._connection.reset_server_context()
+
     @property
     def datetime(self):
         """Current (local) time reported by connection"""
@@ -71,7 +88,6 @@ class Connection:
             self._set_converters()
         return self._converters['user_to_system'](value)
 
-
     def _set_converters(self):
         user = self.bapi_user_get_detail(username=self.user)
         date_converter, time_converter = make_date_time_converters(user.defaults.datfm, user.defaults.timefm)
